@@ -15,6 +15,18 @@ from firebolt.async_db._types import (
 )
 from firebolt.async_db.connection import Connection, connect
 from firebolt.async_db.cursor import Cursor
+from firebolt.common.exception import (
+    DatabaseError,
+    DataError,
+    Error,
+    IntegrityError,
+    InterfaceError,
+    InternalError,
+    NotSupportedError,
+    OperationalError,
+    ProgrammingError,
+    Warning,
+)
 
 apilevel = "2.0"
 # threads may only share the module and connections, cursors should not be shared
