@@ -1,6 +1,7 @@
 from logging import getLogger
 from typing import List, Optional, Union
 
+from firebolt.common.exception import FireboltError
 from firebolt.common.urls import (
     ACCOUNT_ENGINE_BY_NAME_URL,
     ACCOUNT_ENGINE_URL,
@@ -107,7 +108,7 @@ class EngineService(BaseService):
         region: Union[str, Region, None] = None,
         engine_type: Union[str, EngineType] = EngineType.GENERAL_PURPOSE,
         scale: int = 2,
-        spec: str = "i3.4xlarge",
+        spec: Optional[str] = None,
         auto_stop: int = 20,
         warmup: Union[str, WarmupMethod] = WarmupMethod.PRELOAD_INDEXES,
         description: str = "",
@@ -121,7 +122,8 @@ class EngineService(BaseService):
             engine_type: The engine type. GENERAL_PURPOSE or DATA_ANALYTICS
             scale: The number of compute instances on the engine.
                 The scale can be any int from 1 to 128.
-            spec: The AWS EC2 instance type.
+            spec: Firebolt instance type. If not set will default to
+                the cheapest instance.
             auto_stop: The amount of time (in minutes)
             after which the engine automatically stops.
             warmup: The warmup method that should be used.
@@ -162,9 +164,19 @@ class EngineService(BaseService):
             ),
         )
 
-        instance_type_key = self.resource_manager.instance_types.get_by_name(
-            instance_type_name=spec
-        ).key
+        if spec:
+            instance_type_key = self.resource_manager.instance_types.get_by_name(
+                instance_type_name=spec
+            ).key
+        else:
+            instance_type = (
+                self.resource_manager.instance_types.cheapest_instance_in_region(region)
+            )
+            if not instance_type:
+                raise FireboltError(
+                    f"No suitable default instances found in region {region}"
+                )
+            instance_type_key = instance_type.key
 
         engine_revision = EngineRevision(
             specification=EngineRevisionSpecification(
